# Simple Game AI


[![image](https://img.shields.io/pypi/v/sgai.svg)](https://pypi.python.org/pypi/sgai)


**Simple Game AI package allows to easly define an interface for a game and train a simple neural net to play it**


-   Free software: MIT license
-   Documentation: https://John15321.github.io/sgai
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.


```bash
python setup.py sdist
```